@@ -79,11 +79,11 @@
 # If possible, the script will use pdftocairo instead of gs,
 # as it's much faster and gives better results.
 
-import glob, os, pipes, re, string, sys
+import glob, os, pipes, re, sys, tempfile
 
 from lyxpreview_tools import check_latex_log, copyfileobj, error, filter_pages,\
      find_exe, find_exe_or_terminate, join_metrics_and_rename, latex_commands, \
-     latex_file_re, make_texcolor, mkstemp, pdflatex_commands, progress, \
+     latex_file_re, make_texcolor, pdflatex_commands, progress, \
      run_command, run_latex, warning, write_metrics_info
 
 
@@ -97,8 +97,8 @@ def usage(prog_name):
 # Use write_metrics_info to create the .metrics file with this info
 def legacy_extract_metrics_info(log_file):
 
-    log_re = re.compile("Preview: ([ST])")
-    data_re = re.compile("(-?[0-9]+) (-?[0-9]+) (-?[0-9]+) (-?[0-9]+)")
+    log_re = re.compile(b"Preview: ([ST])")
+    data_re = re.compile(b"(-?[0-9]+) (-?[0-9]+) (-?[0-9]+) (-?[0-9]+)")
 
     tp_ascent  = 0.0
     tp_descent = 0.0
@@ -106,20 +106,20 @@ def legacy_extract_metrics_info(log_file):
     success = 0
     results = []
     try:
-        for line in open(log_file, 'r').readlines():
+        for line in open(log_file, 'rb').readlines():
             match = log_re.match(line)
             if match == None:
                 continue
 
-            snippet = (match.group(1) == 'S')
+            snippet = (match.group(1) == b'S')
             success = 1
             match = data_re.search(line)
             if match == None:
                 error("Unexpected data in %s\n%s" % (log_file, line))
 
             if snippet:
-                ascent  = string.atof(match.group(2))
-                descent = string.atof(match.group(3))
+                ascent  = float(match.group(2))
+                descent = float(match.group(3))
 
                 frac = 0.5
                 if ascent == 0 and descent == 0:
@@ -139,14 +139,14 @@ def legacy_extract_metrics_info(log_file):
                 results.append((int(match.group(1)), frac))
 
             else:
-                tp_descent = string.atof(match.group(2))
-                tp_ascent  = string.atof(match.group(4))
+                tp_descent = float(match.group(2))
+                tp_ascent  = float(match.group(4))
 
     except:
         # Unable to open the file, but do nothing here because
         # the calling function will act on the value of 'success'.
         warning('Warning in legacy_extract_metrics_info! Unable to open "%s"' % log_file)
-        warning(`sys.exc_type` + ',' + `sys.exc_value`)
+        warning(repr(sys.exc_info()[0]) + ',' + repr(sys.exc_info()[1]))
 
     if success == 0:
         error("Failed to extract metrics info from %s" % log_file)
@@ -154,10 +154,10 @@ def legacy_extract_metrics_info(log_file):
     return results
 
 def extract_resolution(log_file, dpi):
-    fontsize_re = re.compile("Preview: Fontsize")
-    magnification_re = re.compile("Preview: Magnification")
-    extract_decimal_re = re.compile("([0-9\.]+)")
-    extract_integer_re = re.compile("([0-9]+)")
+    fontsize_re = re.compile(b"Preview: Fontsize")
+    magnification_re = re.compile(b"Preview: Magnification")
+    extract_decimal_re = re.compile(b"([0-9\.]+)")
+    extract_integer_re = re.compile(b"([0-9]+)")
 
     found_fontsize = 0
     found_magnification = 0
@@ -167,7 +167,7 @@ def extract_resolution(log_file, dpi):
     fontsize = 10.0
 
     try:
-        for line in open(log_file, 'r').readlines():
+        for line in open(log_file, 'rb').readlines():
             if found_fontsize and found_magnification:
                 break
 
@@ -177,7 +177,7 @@ def extract_resolution(log_file, dpi):
                     match = extract_decimal_re.search(line)
                     if match == None:
                         error("Unable to parse: %s" % line)
-                    fontsize = string.atof(match.group(1))
+                    fontsize = float(match.group(1))
                     found_fontsize = 1
                     continue
 
@@ -187,13 +187,13 @@ def extract_resolution(log_file, dpi):
                     match = extract_integer_re.search(line)
                     if match == None:
                         error("Unable to parse: %s" % line)
-                    magnification = string.atof(match.group(1))
+                    magnification = float(match.group(1))
                     found_magnification = 1
                     continue
 
     except:
         warning('Warning in extract_resolution! Unable to open "%s"' % log_file)
-        warning(`sys.exc_type` + ',' + `sys.exc_value`)
+        warning(repr(sys.exc_info()[0]) + ',' + repr(sys.exc_info()[1]))
 
     # This is safe because both fontsize and magnification have
     # non-zero default values.
@@ -201,21 +201,21 @@ def extract_resolution(log_file, dpi):
 
 
 def legacy_latex_file(latex_file, fg_color, bg_color):
-    use_preview_re = re.compile(r"\s*\\usepackage\[([^]]+)\]{preview}")
-    use_polyglossia_re = re.compile(r"\s*\\usepackage{polyglossia}")
+    use_polyglossia_re = re.compile(b"\\s*\\\\usepackage{polyglossia}")
+    use_preview_re = re.compile(b"\\s*\\\\usepackage\\[([^]]+)\\]{preview}")
     fg_color_gr = make_texcolor(fg_color, True)
     bg_color_gr = make_texcolor(bg_color, True)
 
-    tmp = mkstemp()
+    tmp = tempfile.TemporaryFile()
 
     success = 0
     try:
-        f = open(latex_file, 'r')
+        f = open(latex_file, 'rb')
     except:
         # Unable to open the file, but do nothing here because
         # the calling function will act on the value of 'success'.
         warning('Warning in legacy_latex_file! Unable to open "%s"' % latex_file)
-        warning(`sys.exc_type` + ',' + `sys.exc_value`)
+        warning(repr(sys.exc_info()[0]) + ',' + repr(sys.exc_info()[1]))
 
     polyglossia = False
     for line in f.readlines():
@@ -235,9 +235,9 @@ def legacy_latex_file(latex_file, fg_color, bg_color):
             else:
                 tmp.write(b"""
 \\usepackage{color}
-\\definecolor{fg}{rgb}{%s}
-\\definecolor{bg}{rgb}{%s}
-\\pagecolor{bg}
+\\definecolor{lyxfg}{rgb}{%s}
+\\definecolor{lyxbg}{rgb}{%s}
+\\pagecolor{lyxbg}
 \\usepackage{polyglossia}
 """ % (fg_color_gr, bg_color_gr))
                 polyglossia = True
@@ -246,28 +246,28 @@ def legacy_latex_file(latex_file, fg_color, bg_color):
         # Preview options: add the options lyx and tightpage
         previewopts = match.group(1)
         if not polyglossia:
-            tmp.write(r"""
-\usepackage{color}
-\definecolor{fg}{rgb}{%s}
-\definecolor{bg}{rgb}{%s}
-\pagecolor{bg}
-\usepackage[%s,tightpage]{preview}
-\makeatletter
-\def\t@a{cmr}
-\if\f@family\t@a
-\IfFileExists{lmodern.sty}{\usepackage{lmodern}}{\usepackage{ae,aecompl}}
-\fi
-\g@addto@macro\preview{\begingroup\color{bg}\special{ps::clippath fill}\color{fg}}
-\g@addto@macro\endpreview{\endgroup}
-\makeatother
+            tmp.write(b"""
+\\usepackage{color}
+\\definecolor{lyxfg}{rgb}{%s}
+\\definecolor{lyxbg}{rgb}{%s}
+\\pagecolor{lyxbg}
+\\usepackage[%s,tightpage]{preview}
+\\makeatletter
+\\def\\t@a{cmr}
+\\if\\f@family\\t@a
+\\IfFileExists{lmodern.sty}{\\usepackage{lmodern}}{\\usepackage{ae,aecompl}}
+\\fi
+\\g@addto@macro\\preview{\\begingroup\\color{lyxbg}\\special{ps::clippath fill}\\color{lyxfg}}
+\\g@addto@macro\\endpreview{\\endgroup}
+\\makeatother
 """ % (fg_color_gr, bg_color_gr, previewopts))
         else:
-            tmp.write(r"""
-\usepackage[%s,tightpage]{preview}
-\makeatletter
-\g@addto@macro\preview{\begingroup\color{bg}\special{ps::clippath fill}\color{fg}}
-\g@addto@macro\endpreview{\endgroup}
-\makeatother
+            tmp.write(b"""
+\\usepackage[%s,tightpage]{preview}
+\\makeatletter
+\\g@addto@macro\\preview{\\begingroup\\color{lyxbg}\\special{ps::clippath fill}\\color{lyxfg}}
+\\g@addto@macro\\endpreview{\\endgroup}
+\\makeatother
 """ % previewopts)
     if success:
         copyfileobj(tmp, open(latex_file,"wb"), 1)
@@ -281,7 +281,7 @@ def crop_files(pnmcrop, basename):
     t.append('%s -right' % pnmcrop, '--')
 
     for file in glob.glob("%s*.ppm" % basename):
-        tmp = mkstemp()
+        tmp = tempfile.TemporaryFile()
         new = t.open(file, "r")
         copyfileobj(new, tmp)
         if not new.close():
@@ -301,7 +301,7 @@ def legacy_conversion(argv, skipMetrics = False):
     if len(dir) != 0:
         os.chdir(dir)
 
-    dpi = string.atoi(argv[2])
+    dpi = int(argv[2])
 
     output_format = argv[3]
 
@@ -443,6 +443,10 @@ def legacy_conversion_step3(latex_file, dpi, output_format, dvips_failed, skipMe
     pdftocairo = find_exe(["pdftocairo"])
     epstopdf   = find_exe(["epstopdf"])
     use_pdftocairo = pdftocairo != None and output_format == "png"
+    if use_pdftocairo and os.name == 'nt':
+        # On Windows, check for png support (see #10718)
+        conv_status, conv_stdout = run_command("%s --help" % pdftocairo)
+        use_pdftocairo = '-png' in conv_stdout
     if use_pdftocairo:
         conv = pdftocairo
     else:
