@@ -331,12 +331,13 @@ Buffer * BufferList::getBuffer(support::FileName const & fname, bool internal) c
 }
 
 
-Buffer * BufferList::getBufferFromTmp(string const & s)
+Buffer * BufferList::getBufferFromTmp(string const & s, bool realpath)
 {
 	BufferStorage::iterator it = bstore.begin();
 	BufferStorage::iterator end = bstore.end();
 	for (; it < end; ++it) {
-		if (prefixIs(s, (*it)->temppath())) {
+		string const temppath = realpath ? FileName((*it)->temppath()).realPath() : (*it)->temppath();
+		if (prefixIs(s, temppath)) {
 			// check whether the filename matches the master
 			string const master_name = (*it)->latexName();
 			if (suffixIs(s, master_name))
