@@ -835,7 +835,10 @@ void switchBetweenClasses(DocumentClassConstPtr oldone,
 			docstring const & n = newone->insetLayout(layoutName).name();
 			bool const is_undefined = n.empty() ||
 				n == DocumentClass::plainInsetLayout().name();
-			if (!is_undefined)
+			docstring const & oldn = oldone->insetLayout(layoutName).name();
+			bool const was_undefined = oldn.empty() ||
+				oldn == DocumentClass::plainInsetLayout().name();
+			if (!is_undefined || was_undefined)
 				continue;
 
 			// The flex inset is undefined in newtc
@@ -1140,7 +1143,7 @@ void clearCutStack()
 }
 
 
-docstring selection(size_t sel_index, DocumentClassConstPtr docclass)
+docstring selection(size_t sel_index, DocumentClassConstPtr docclass, bool for_math)
 {
 	if (sel_index >= theCuts.size())
 		return docstring();
@@ -1150,7 +1153,11 @@ docstring selection(size_t sel_index, DocumentClassConstPtr docclass)
 	if (!buffer)
 		return docstring();
 
-	return buffer->paragraphs().back().asString(AS_STR_INSETS | AS_STR_NEWLINES);
+	int options = AS_STR_INSETS | AS_STR_NEWLINES;
+	if (for_math)
+		options |= AS_STR_MATHED;
+
+	return buffer->paragraphs().back().asString(options);
 }
 
 
@@ -1218,6 +1225,7 @@ bool pasteClipboardText(Cursor & cur, ErrorList & errorList, bool asParagraphs,
 			// For some strange reason gcc 3.2 and 3.3 do not accept
 			// Buffer buffer(string(), false);
 			Buffer buffer("", false);
+			buffer.setInternal(true);
 			buffer.setUnnamed(true);
 			if (buffer.readString(lyx)) {
 				cur.recordUndo();
@@ -1251,6 +1259,7 @@ bool pasteClipboardText(Cursor & cur, ErrorList & errorList, bool asParagraphs,
 				// For some strange reason gcc 3.2 and 3.3 do not accept
 				// Buffer buffer(string(), false);
 				Buffer buffer("", false);
+				buffer.setInternal(true);
 				buffer.setUnnamed(true);
 				available = buffer.importString(names[i], text, errorList);
 				if (available)
