@@ -267,7 +267,7 @@ vector<char_type> Encoding::symbolsList() const
 	// add all encodable characters
 	copy(encodable_.begin(), encodable_.end(), back_inserter(symbols));
 	// now the ones from the unicodesymbols file that are not already there
-	for (pair<char_type, CharInfo> const & elem : unicodesymbols) {
+	for (pair<const char_type, CharInfo> const & elem : unicodesymbols) {
 		if (find(symbols.begin(), symbols.end(), elem.first) == symbols.end())
 			symbols.push_back(elem.first);
 	}
@@ -306,10 +306,11 @@ bool Encodings::latexMathChar(char_type c, bool mathmode,
 		if (!encoding || command.empty()) {
 			command = it->second.textcommand();
 			needsTermination = !it->second.textnotermination();
-			addTextCmd(c);
 		}
 		if (mathmode)
 			addMathSym(c);
+		else
+			addTextCmd(c);
 	}
 	return use_math;
 }
