@@ -175,11 +175,11 @@ bool Language::readLanguage(Lexer & lex)
 			break;
 		case LA_POSTBABELPREAMBLE:
 			babel_postsettings_ =
-				lex.getLongString("EndPostBabelPreamble");
+				lex.getLongString(from_ascii("EndPostBabelPreamble"));
 			break;
 		case LA_PREBABELPREAMBLE:
 			babel_presettings_ =
-				lex.getLongString("EndPreBabelPreamble");
+				lex.getLongString(from_ascii("EndPreBabelPreamble"));
 			break;
 		case LA_REQUIRES:
 			lex >> requires_;
@@ -329,7 +329,7 @@ Match match(string const & code, Language const & lang)
 	return NoMatch;
 }
 
-}
+} // namespace
 
 
 void Languages::readLayoutTranslations(support::FileName const & filename)
