@@ -59,11 +59,15 @@ int VCS::doVCCommand(string const & cmd, FileName const & path, bool reportError
 
 	if (owner_)
 		owner_->setBusy(false);
-	if (ret && reportError)
+	if (ret && reportError) {
+		docstring rcsmsg;
+		if (prefixIs(cmd, "ci "))
+			rcsmsg = "\n" + _("Check whether the GNU RCS package is installed on your system.");
 		frontend::Alert::error(_("Revision control error."),
 			bformat(_("Some problem occurred while running the command:\n"
-				  "'%1$s'."),
+				  "'%1$s'.") + rcsmsg,
 			from_utf8(cmd)));
+	}
 	return ret;
 }
 
