@@ -63,6 +63,7 @@
 #include "support/convert.h"
 #include "support/debug.h"
 #include "support/ExceptionMessage.h"
+#include "support/environment.h"
 #include "support/FileName.h"
 #include "support/filetools.h"
 #include "support/ForkedCalls.h"
@@ -105,6 +106,9 @@
 #include <QObject>
 #include <QPixmap>
 #include <QPixmapCache>
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+#include <QRandomGenerator>
+#endif
 #include <QRegExp>
 #include <QSessionManager>
 #include <QSettings>
@@ -194,6 +198,24 @@ frontend::Application * createApplication(int & argc, char * argv[])
 	AllowSetForegroundWindow(ASFW_ANY);
 #endif
 
+
+// Setup high DPI handling. This is a bit complicated, but will be default in Qt6.
+// macOS does it by itself.
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0) && !defined(Q_OS_MAC)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
+    // Attribute Qt::AA_EnableHighDpiScaling must be set before QCoreApplication is created
+    if (getEnv("QT_ENABLE_HIGHDPI_SCALING").empty()
+		&& getEnv("QT_AUTO_SCREEN_SCALE_FACTOR").empty())
+        QApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
+#endif
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+    // HighDPI scale factor policy must be set before QGuiApplication is created
+    if (getEnv("QT_SCALE_FACTOR_ROUNDING_POLICY").empty())
+        QApplication::setHighDpiScaleFactorRoundingPolicy(Qt::HighDpiScaleFactorRoundingPolicy::PassThrough);
+#endif
+#endif
+
 	frontend::GuiApplication * guiApp = new frontend::GuiApplication(argc, argv);
 	// I'd rather do that in the constructor, but I do not think that
 	// the palette is accessible there.
@@ -1031,7 +1053,11 @@ GuiApplication::GuiApplication(int & argc, char ** argv)
 	setDesktopFileName(lyx_package);
 #endif
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+	QRandomGenerator(QDateTime::currentDateTime().toSecsSinceEpoch());
+#else
 	qsrand(QDateTime::currentDateTime().toTime_t());
+#endif
 
 	// Install translator for GUI elements.
 	installTranslator(&d->qt_trans_);
@@ -1111,6 +1137,29 @@ GuiApplication * theGuiApp()
 }
 
 
+#if QT_VERSION < 0x050000
+// Emulate platformName() for Qt4
+
+// FIXME: when ditching this method, remove all tests
+//     platformName() == "qt4x11"
+// in the code
+QString GuiApplication::platformName() const
+{
+# if defined(Q_WS_X11)
+	// Note that this one does not really exist
+	return "qt4x11";
+# elif defined(Q_OS_MAC)
+	return "cocoa";
+# elif defined(Q_OS_WIN) || defined(Q_CYGWIN_WIN)
+	return "windows";
+# else
+	LYXERR0("Unknown platform!");
+	return "unknown";
+# endif
+}
+#endif
+
+
 double GuiApplication::pixelRatio() const
 {
 #if QT_VERSION >= 0x050000
@@ -2460,6 +2509,26 @@ Menus & GuiApplication::menus()
 }
 
 
+bool GuiApplication::needsBackingStore() const
+{
+	/* Qt on macOS and Wayland does not respect the
+	 * Qt::WA_OpaquePaintEvent attribute and resets the widget backing
+	 * store at each update. Therefore, we use our own backing store
+	 * in these two cases. It is also possible to force the use of the
+	 * backing store for cases like x11 with transparent WM themes.
+	 */
+#if QT_VERSION >= 0x050000
+	return platformName() == "cocoa" || platformName().contains("wayland");
+#else
+#  ifdef Q_OS_MAC
+	return true;
+#  else
+    return false;
+#  endif // Q_OS_MAC
+#endif // QT_VERSION
+}
+
+
 QList<int> GuiApplication::viewIds() const
 {
 	return d->views_.keys();
