@@ -79,7 +79,7 @@ protected:
 	}
 };
 
-} // end of anon
+} // namespace
 
 
 GuiCommandBuffer::GuiCommandBuffer(GuiView * view)
@@ -128,11 +128,11 @@ GuiCommandBuffer::GuiCommandBuffer(GuiView * view)
 	top->setMargin(0);
 	setFocusProxy(edit_);
 
-	LastCommandsSection::LastCommands last_commands 
+	LastCommandsSection::LastCommands last_commands
 		= theSession().lastCommands().getcommands();
-	LastCommandsSection::LastCommands::const_iterator it 
+	LastCommandsSection::LastCommands::const_iterator it
 		= last_commands.begin();
-	LastCommandsSection::LastCommands::const_iterator end 
+	LastCommandsSection::LastCommands::const_iterator end
 		= last_commands.end();
 
 	upPB->setEnabled(it != end);
@@ -231,7 +231,6 @@ void GuiCommandBuffer::itemSelected(QListWidgetItem * item)
 
 void GuiCommandBuffer::up()
 {
-	string const input = fromqstr(edit_->text());
 	string const h = historyUp();
 
 	if (!h.empty())
@@ -244,7 +243,6 @@ void GuiCommandBuffer::up()
 
 void GuiCommandBuffer::down()
 {
-	string const input = fromqstr(edit_->text());
 	string const h = historyDown();
 
 	if (!h.empty())
@@ -254,7 +252,7 @@ void GuiCommandBuffer::down()
 			   && history_pos_ != history_.end() - 1);
 	upPB->setEnabled(history_pos_ != history_.begin());
 }
-	
+
 
 void GuiCommandBuffer::hideParent()
 {
@@ -274,7 +272,7 @@ public:
 	bool operator()(string const & s) const { return prefixIs(s, p); }
 };
 
-} // end of anon namespace
+} // namespace
 
 
 string const GuiCommandBuffer::historyUp()
@@ -297,12 +295,6 @@ string const GuiCommandBuffer::historyDown()
 }
 
 
-docstring const GuiCommandBuffer::getCurrentState() const
-{
-	return view_->currentBufferView()->cursor().currentState();
-}
-
-
 vector<string> const
 GuiCommandBuffer::completions(string const & prefix, string & new_prefix)
 {
