@@ -18,13 +18,23 @@
 #include "Dimension.h"
 
 #include "support/convert.h"
+#include "support/debug.h"
 #include "support/lassert.h"
 #include "support/lyxlib.h"
+#include "support/textutils.h"
 
 #define DISABLE_PMPROF
 #include "support/pmprof.h"
 
 #include <QByteArray>
+#include <QRawFont>
+#include <QtEndian>
+
+#if QT_VERSION >= 0x050100
+#include <QtMath>
+#else
+#define qDegreesToRadians(degree) (degree) * (M_PI / 180)
+#endif
 
 using namespace std;
 using namespace lyx::support;
@@ -106,13 +116,27 @@ inline QChar const ucs4_to_qchar(char_type const ucs4)
 }
 } // namespace
 
-
 GuiFontMetrics::GuiFontMetrics(QFont const & font)
 	: font_(font), metrics_(font, 0),
 	  strwidth_cache_(cache_metrics_width_size),
 	  breakat_cache_(cache_metrics_breakat_size),
 	  qtextlayout_cache_(cache_metrics_qtextlayout_size)
 {
+	// Determine italic slope
+	double const defaultSlope = tan(qDegreesToRadians(19.0));
+	QRawFont raw = QRawFont::fromFont(font);
+	QByteArray post(raw.fontTable("post"));
+	if (post.length() == 0) {
+		slope_ = defaultSlope;
+		LYXERR(Debug::FONT, "Screen font doesn't have 'post' table.");
+	} else {
+		// post table description:
+		// https://developer.apple.com/fonts/TrueType-Reference-Manual/RM06/Chap6post.html
+		int32_t italicAngle = qFromBigEndian(*reinterpret_cast<int32_t *>(post.data() + 4));
+		double angle = italicAngle / 65536.0; // Fixed-point 16.16 to floating-point
+		slope_ = -tan(qDegreesToRadians(angle));
+		LYXERR(Debug::FONT, "Italic slope: " << slope_);
+	}
 }
 
 
@@ -154,6 +178,12 @@ int GuiFontMetrics::strikeoutPos() const
 }
 
 
+double GuiFontMetrics::italicSlope() const
+{
+	return slope_;
+}
+
+
 namespace {
 int const outOfLimitMetric = -10000;
 }
@@ -395,7 +425,7 @@ int GuiFontMetrics::countExpanders(docstring const & str) const
 	bool wasspace = false;
 	int nexp = 0;
 	for (char_type c : str)
-		if (c > 0x0d && QChar(c).isSpace()) {
+		if (c > 0x0d && isSpace(c)) {
 			if (!wasspace) {
 				++nexp;
 				wasspace = true;
@@ -563,10 +593,17 @@ int GuiFontMetrics::width(char_type c) const
 	if (value != outOfLimitMetric)
 		return value;
 
+#if QT_VERSION >= 0x050b00
+	if (is_utf16(c))
+		value = metrics_.horizontalAdvance(ucs4_to_qchar(c));
+	else
+		value = metrics_.horizontalAdvance(toqstr(docstring(1, c)));
+#else
 	if (is_utf16(c))
 		value = metrics_.width(ucs4_to_qchar(c));
 	else
 		value = metrics_.width(toqstr(docstring(1, c)));
+#endif
 
 	width_cache_.insert(c, value);
 
