@@ -47,7 +47,7 @@ public:
 	GuiProgressView(
 		GuiView & parent, ///< the main window where to dock.
 		Qt::DockWidgetArea area, ///< Position of the dock (and also drawer)
-		Qt::WindowFlags flags = 0);
+		Qt::WindowFlags flags = {});
 
 	~GuiProgressView();
 	/// Controller inherited method.
