@@ -206,7 +206,7 @@ void GuiRef::refHighlighted(QTreeWidgetItem * sel)
 /*	int const cur_item = refsTW->currentRow();
 	bool const cur_item_selected = cur_item >= 0 ?
 		refsLB->isSelected(cur_item) : false;*/
-	bool const cur_item_selected = refsTW->isItemSelected(sel);
+	bool const cur_item_selected = sel->isSelected();
 
 	if (cur_item_selected)
 		referenceED->setText(sel->text(0));
@@ -242,7 +242,7 @@ void GuiRef::refSelected(QTreeWidgetItem * sel)
 /*	int const cur_item = refsTW->currentRow();
 	bool const cur_item_selected = cur_item >= 0 ?
 		refsLB->isSelected(cur_item) : false;*/
-	bool const cur_item_selected = refsTW->isItemSelected(sel);
+	bool const cur_item_selected = sel->isSelected();
 
 	if (cur_item_selected)
 		referenceED->setText(sel->text(0));
@@ -471,19 +471,19 @@ void GuiRef::redoRefs()
 		}
 	}
 	// sort categories case-intensively
-	qSort(refsCategories.begin(), refsCategories.end(),
+	sort(refsCategories.begin(), refsCategories.end(),
 	      caseInsensitiveLessThan /*defined above*/);
 	if (noprefix)
 		refsCategories.insert(0, qt_("<No prefix>"));
 
-	QString const sort = sortingCO->isEnabled() ?
+	QString const sort_method = sortingCO->isEnabled() ?
 				sortingCO->itemData(sortingCO->currentIndex()).toString()
 				: QString();
-	if (sort == "nocase")
-		qSort(refsStrings.begin(), refsStrings.end(),
+	if (sort_method == "nocase")
+		sort(refsStrings.begin(), refsStrings.end(),
 		      caseInsensitiveLessThan /*defined above*/);
-	else if (sort == "case")
-		qSort(refsStrings.begin(), refsStrings.end());
+	else if (sort_method == "case")
+		sort(refsStrings.begin(), refsStrings.end());
 
 	if (groupCB->isChecked()) {
 		QList<QTreeWidgetItem *> refsCats;
@@ -526,7 +526,7 @@ void GuiRef::redoRefs()
 		while (*it) {
 			if ((*it)->text(0) == textToFind) {
 				refsTW->setCurrentItem(*it);
-				refsTW->setItemSelected(*it, true);
+				(*it)->setSelected(true);
 				//Make sure selected item is visible
 				refsTW->scrollToItem(*it);
 				last_reference_ = textToFind;
