@@ -368,6 +368,13 @@ void SpellcheckerWidget::Private::forward()
 	if (isWrapAround(cursor())) {
 		hide();
 	}
+	// If we reached the end of the document
+	// and have not yet wrapped (which was
+	// checked above), continue from beginning
+	if (cursor().pit() == cursor().lastpit()
+	    && cursor().pos() == cursor().lastpos()
+	    && cursor().text()->isMainText())
+		continueFromBeginning();
 }
 
 
@@ -490,8 +497,6 @@ void SpellcheckerWidget::on_replaceAllPB_clicked()
 	LYXERR(Debug::GUI, "Replace all (" << replacement << ")");
 	dispatch(FuncRequest(LFUN_WORD_REPLACE, datastring));
 	d->forward();
-	// replace all wraps around
-	d->wrapAround(true);
 	d->check(); // continue spellchecking
 	d->canCheck();
 }
