@@ -245,20 +245,10 @@ GuiWorkArea::Private::Private(GuiWorkArea * parent)
   dialog_mode_(false), shell_escape_(false), read_only_(false),
   clean_(true), externally_modified_(false), needs_caret_geometry_update_(true)
 {
-/* Qt on macOS and Wayland does not respect the
- * Qt::WA_OpaquePaintEvent attribute and resets the widget backing
- * store at each update. Therefore, we use our own backing store in
- * these two cases. */
-#if QT_VERSION >= 0x050000
-	use_backingstore_ = guiApp->platformName() == "cocoa"
-		|| guiApp->platformName().contains("wayland");
-#else
-#  ifdef Q_OS_MAC
-	use_backingstore_ = true;
-#  else
-	use_backingstore_ = false;
-#  endif
-#endif
+	use_backingstore_ = lyxrc.draw_strategy == LyXRC::DS_BACKINGSTORE
+		|| guiApp->needsBackingStore();
+	LYXERR(Debug::WORKAREA, "Drawing strategy is: "
+	                        << (use_backingstore_ ? "backingstore" : "partial"));
 
 	int const time = QApplication::cursorFlashTime() / 2;
 	if (time > 0) {
@@ -1956,8 +1946,13 @@ public:
 		filename_ = (filename.extension() == "lyx") ?
 			toqstr(filename.onlyFileNameWithoutExt())
 			: toqstr(filename.onlyFileName());
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
+		postfix_ = toqstr(filename.absoluteFilePath()).
+			split("/", Qt::SkipEmptyParts);
+#else
 		postfix_ = toqstr(filename.absoluteFilePath()).
 			split("/", QString::SkipEmptyParts);
+#endif
 		postfix_.pop_back();
 		abs_ = toqstr(filename.absoluteFilePath());
 		dottedPrefix_ = false;
