@@ -271,7 +271,11 @@ void LayoutItemDelegate::drawCategoryHeader(QPainter * painter, QStyleOptionView
 
 	// draw the centered text
 	QFontMetrics fm(font);
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
+	int w = fm.horizontalAdvance(category);
+#else
 	int w = fm.width(category);
+#endif
 	int x = opt.rect.x() + (opt.rect.width() - w) / 2;
 	int y = opt.rect.y() + fm.ascent();
 	int left = x;
