@@ -19,6 +19,8 @@
 #include "support/filetools.h"
 #include "qt_i18n.h"
 
+#include <list>
+
 #include <QHeaderView>
 
 class QComboBox;
@@ -33,7 +35,7 @@ namespace lyx {
 namespace support { class FileName; }
 
 class BufferParams;
- 
+
 namespace frontend {
 
 class LengthCombo;
@@ -48,11 +50,11 @@ Length widgetsToLength(QLineEdit const * input, QComboBox const * combo);
 // all the code to remove default_unit argument when equal to the
 // default.
 void lengthToWidgets(QLineEdit * input, LengthCombo * combo,
-		     Length const & len, 
+		     Length const & len,
 		     Length::UNIT default_unit = Length::defaultUnit());
 /// method to set widgets from a string
 void lengthToWidgets(QLineEdit * input, LengthCombo * combo,
-		     std::string const & len, 
+		     std::string const & len,
 		     Length::UNIT default_unit = Length::defaultUnit());
 /// method to set widgets from a docstring
 void lengthToWidgets(QLineEdit * input, LengthCombo * combo,
@@ -74,12 +76,23 @@ void doubleToWidget(QLineEdit * input, std::string const & value,
  */
 QString formatLocFPNumber(double d);
 
+/// Method to sort QStrings locale-aware (e.g. in combo widgets)
+bool SortLocaleAware(QString const & lhs, QString const & rhs);
+
 /// Method to sort colors by GUI name in combo widgets
 bool ColorSorter(ColorCode lhs, ColorCode rhs);
 
 /// colors a widget red if invalid
 void setValid(QWidget * widget, bool valid);
 
+// set focus and highlight the current item if there is no selection already
+void focusAndHighlight(QAbstractItemView * w);
+
+// Sets all widget in highlighted in highlighted colour, and their children in
+// plain in standard colours.
+void setMessageColour(std::list<QWidget *> highlighted,
+                      std::list<QWidget *> plain);
+
 /// Qt5 changed setSectionMode to setSectionResizeMode
 /// These wrappers work for Qt4 and Qt5
 void setSectionResizeMode(QHeaderView * view,
@@ -113,18 +126,18 @@ support::FileName imageLibFileSearch(QString & dir, QString const & name,
 	relative to relpath.
 
 \param title: title for dialog
-	
+
 \param filters: *.ps, etc
 
 \param save: whether to save dialog info (current path, etc) for next use.
 
-The \param labelN and \param dirN arguments provide for extra buttons 
+The \param labelN and \param dirN arguments provide for extra buttons
 in the dialog (e.g., "Templates" and a path to that directory).
 
-The difference between the functions concerns when we think we have a 
-relative path. 
+The difference between the functions concerns when we think we have a
+relative path.
 
-In \c browseRelToParent, we return a relative path only if it IS NOT of 
+In \c browseRelToParent, we return a relative path only if it IS NOT of
 	the form "../../foo.txt".
 
 In \c browseRelToSub, we return a relative path only if it IS of the
@@ -191,9 +204,23 @@ QString getExtension(QString const & name);
 QString makeAbsPath(QString const & relpath, QString const & base);
 QString changeExtension(QString const & oldname, QString const & ext);
 
-/// \return the display string associated with given type and buffer
-/// parameter.
-QString guiName(std::string const & type, BufferParams const & bp);
+/// Format \param text for display as a ToolTip, breaking at lines of \param
+/// width ems. Note: this function is expensive. Better call it in a delayed
+/// manner, i.e. not to fill in a model (see for instance the function
+/// ToolTipFormatter::eventFilter).
+///
+/// When is it called automatically? Whenever the tooltip is not already rich
+/// text beginning with <html>, and is defined by the following functions:
+///  - QWidget::setToolTip(),
+///  - QAbstractItemModel::setData(..., Qt::ToolTipRole),
+///  - Inset::toolTip()
+///
+/// In other words, tooltips can use Qt html, and the tooltip will still be
+/// correctly broken. Moreover, it is possible to specify an entirely custom
+/// tooltip (not subject to automatic formatting) by giving it in its entirety,
+/// i.e. starting with <html>.
+QString formatToolTip(QString text, int width = 30);
+
 
 #if QT_VERSION < 0x050300
 // Very partial implementation of QSignalBlocker for archaic qt versions.
@@ -213,6 +240,11 @@ private:
 #endif
 
 
+// Check if qstr is understood as rich text (Qt HTML) and if so, produce a
+// rendering in plain text.
+QString qtHtmlToPlainText(QString const & qstr);
+
+
 } // namespace lyx
 
 #endif // QTHELPERS_H
