@@ -15,31 +15,35 @@
 #ifndef INSET_CAPTIONABLE_H
 #define INSET_CAPTIONABLE_H
 
-#include "InsetCollapsable.h"
+#include "InsetCollapsible.h"
 
 
 namespace lyx {
 
-class InsetCaptionable : public InsetCollapsable
+class InsetCaptionable : public InsetCollapsible
 {
 public:
-	InsetCaptionable(Buffer * buffer)
-		: InsetCollapsable(buffer), caption_type_("senseless") {}
-	InsetCaptionable(Buffer * buffer, std::string const & type)
-		: InsetCollapsable(buffer), caption_type_(type) {}
+	InsetCaptionable(Buffer * buffer, std::string const & type = "senseless")
+		: InsetCollapsible(buffer), caption_type_(type) {}
 	///
 	std::string const & captionType() const { return caption_type_; }
 	///
 	docstring floatName(std::string const & type) const;
 	///
 protected:
+	///
+	InsetCaption const * getCaptionInset() const;
+	///
+	docstring getCaptionText(OutputParams const &) const;
+	///
+	docstring getCaptionHTML(OutputParams const &) const;
 	///
 	virtual void setCaptionType(std::string const & type);
 	/// are our captions subcaptions?
 	virtual bool hasSubCaptions(ParIterator const &) const { return false; }
 	///
 	void addToToc(DocIterator const & di, bool output_active,
-				  UpdateType utype) const;
+				  UpdateType utype, TocBackend & backend) const;
 	/// Update the counters of this inset and of its contents
 	void updateBuffer(ParIterator const &, UpdateType);
 	///
