@@ -78,6 +78,8 @@ public:
 	///
 	void draw(PainterInfo & pi, int x, int y) const;
 	///
+	virtual void drawBackground(PainterInfo &, int, int) const {}
+	///
 	void latex(otexstream &, OutputParams const &) const;
 	///
 	int plaintext(odocstringstream & ods, OutputParams const & op,
@@ -85,6 +87,8 @@ public:
 	///
 	int docbook(odocstream &, OutputParams const & runparams) const;
 	///
+	void validate(LaTeXFeatures & features) const;
+	///
 	bool setMouseHover(BufferView const * bv, bool mouse_hover) const;
 	///
 	bool clickable(BufferView const &, int, int) const { return hasSettings(); }
@@ -97,9 +101,6 @@ protected:
 	std::string contextMenuName() const;
 	///
 	bool showInsetDialog(BufferView * bv) const;
-	///
-	Dimension const dimension(BufferView const &) const 
-		{ return button_.dimension(); }
 	//@}
 
 protected:
@@ -107,7 +108,7 @@ protected:
 	//@{
 	/// Build the complete LaTeX command
 	/// \see InsetCommandParams::getCommand
-	docstring const getCommand(OutputParams const & rp) const 
+	docstring const getCommand(OutputParams const & rp) const
 		{ return p_.getCommand(rp); }
 	/// Return the command name
 	/// \see InsetCommandParams::getCmdName
