@@ -17,9 +17,7 @@
 #include "ExternalTemplate.h"
 
 #include "support/FileName.h"
-
-#include <boost/scoped_ptr.hpp>
-#include <boost/signals/trackable.hpp>
+#include "support/unique_ptr.h"
 
 
 namespace lyx {
@@ -90,7 +88,7 @@ private:
 class RenderBase;
 
 ///
-class InsetExternal : public Inset, public boost::signals::trackable
+class InsetExternal : public Inset
 {
 	// Disable assignment operator, since it is not used, and it is too
 	// complicated to implement it consistently with the copy constructor
@@ -121,7 +119,7 @@ public:
 	bool clickable(BufferView const &, int, int) const { return true; }
 	///
 	void addToToc(DocIterator const & di, bool output_active,
-				  UpdateType utype) const;
+				  UpdateType utype, TocBackend & backend) const;
 private:
 	///
 	InsetExternal(InsetExternal const &);
@@ -173,7 +171,7 @@ private:
 	/// The current params
 	InsetExternalParams params_;
 	/// The thing that actually draws the image on LyX's screen.
-	mutable boost::scoped_ptr<RenderBase> renderer_;
+	mutable unique_ptr<RenderBase> renderer_;
 	/// changes color of the button when mouse enters/leaves this inset
 	mutable std::map<BufferView const *, bool> mouse_hover_;
 };
