@@ -16,7 +16,8 @@
 
 #include "Dimension.h"
 
-#include <boost/scoped_ptr.hpp>
+#include "support/unique_ptr.h"
+
 
 namespace lyx {
 
@@ -28,7 +29,7 @@ namespace graphics {
 
 /// An IPA inset with instant preview
 class InsetIPA : public InsetText {
-	
+
 public:
 	///
 	InsetIPA(Buffer *);
@@ -46,11 +47,11 @@ public:
 	bool neverIndent() const { return true; }
 
 	bool forceLocalFontSwitch() const { return true; }
-	
+
 	InsetCode lyxCode() const { return IPA_CODE; }
-	
+
 	docstring layoutName() const { return from_ascii("IPA"); }
-	
+
 	bool descendable(BufferView const & /*bv*/) const { return true; }
 
 	void metrics(MetricsInfo & mi, Dimension & dim) const;
@@ -72,7 +73,7 @@ public:
 	void write(std::ostream & os) const;
 
 	void edit(Cursor & cur, bool front, EntryDirection entry_from);
-	
+
 	///
 	void latex(otexstream &, OutputParams const &) const;
 	///
@@ -84,7 +85,7 @@ public:
 	///
 	bool insetAllowed(InsetCode code) const;
 	//@}
-	
+
 protected:
 	/// Retrieves the preview state. Returns true if preview
 	/// is enabled and the preview image is availabled.
@@ -95,7 +96,7 @@ protected:
 	void preparePreview(DocIterator const & pos) const;
 
 	///
-	boost::scoped_ptr<RenderPreview> preview_;
+	unique_ptr<RenderPreview> preview_;
 };
 
 
