@@ -74,10 +74,11 @@ InsetLayout::InsetLaTeXType translateLaTeXType(std::string const & str)
 	return InsetLayout::ILT_ERROR;
 }
 
-} // namespace anon
+} // namespace
 
 
-bool InsetLayout::read(Lexer & lex, TextClass const & tclass)
+bool InsetLayout::read(Lexer & lex, TextClass const & tclass,
+	bool validating)
 {
 	enum {
 		IL_ADDTOTOC,
@@ -203,6 +204,8 @@ bool InsetLayout::read(Lexer & lex, TextClass const & tclass)
 		switch (le) {
 		case Lexer::LEX_UNDEF:
 			lex.printError("Unknown InsetLayout tag");
+			if (validating)
+				return false;
 			continue;
 		default:
 			break;
@@ -219,13 +222,20 @@ bool InsetLayout::read(Lexer & lex, TextClass const & tclass)
 				LYXERR0("Flex insets must have names of the form `Flex:<name>'.\n"
 				        "This one has the name `" << to_utf8(name_) << "'\n"
 				        "Ignoring LyXType declaration.");
+				// this is not really a reason to abort
+				if (validating)
+					return false;
 				break;
 			}
 			string lt;
 			lex >> lt;
 			lyxtype_ = translateLyXType(lt);
-			if (lyxtype_  == NOLYXTYPE)
+			if (lyxtype_  == NOLYXTYPE) {
 				LYXERR0("Unknown LyXType `" << lt << "'.");
+				// this is not really a reason to abort
+				if (validating)
+					return false;
+			}
 			if (lyxtype_ == CHARSTYLE) {
 				// by default, charstyles force the plain layout
 				multipar_ = false;
@@ -237,8 +247,12 @@ bool InsetLayout::read(Lexer & lex, TextClass const & tclass)
 			string lt;
 			lex >> lt;
 			latextype_ = translateLaTeXType(lt);
-			if (latextype_  == ILT_ERROR)
+			if (latextype_  == ILT_ERROR) {
 				LYXERR0("Unknown LaTeXType `" << lt << "'.");
+				// this is not really a reason to abort
+				if (validating)
+					return false;
+			}
 			break;
 		}
 		case IL_LABELSTRING:
@@ -350,6 +364,9 @@ bool InsetLayout::read(Lexer & lex, TextClass const & tclass)
 						tclass.insetLayouts().end();
 				for (; lit != len; ++lit)
 					lyxerr << lit->second.name() << "\n";
+				// this is not really a reason to abort
+				if (validating)
+					return false;
 			}
 			break;
 		}
@@ -380,6 +397,9 @@ bool InsetLayout::read(Lexer & lex, TextClass const & tclass)
 						tclass.insetLayouts().end();
 				for (; lit != len; ++lit)
 					lyxerr << lit->second.name() << "\n";
+				// this is not really a reason to abort
+				if (validating)
+					return false;
 			}
 			break;
 		}
@@ -407,13 +427,13 @@ bool InsetLayout::read(Lexer & lex, TextClass const & tclass)
 			bgcolor_ = lcolor.getFromLyXName(tmp);
 			break;
 		case IL_PREAMBLE:
-			preamble_ = from_utf8(lex.getLongString("EndPreamble"));
+			preamble_ = lex.getLongString(from_ascii("EndPreamble"));
 			break;
 		case IL_BABELPREAMBLE:
-			babelpreamble_ = from_utf8(lex.getLongString("EndBabelPreamble"));
+			babelpreamble_ = lex.getLongString(from_ascii("EndBabelPreamble"));
 			break;
 		case IL_LANGPREAMBLE:
-			langpreamble_ = from_utf8(lex.getLongString("EndLangPreamble"));
+			langpreamble_ = lex.getLongString(from_ascii("EndLangPreamble"));
 			break;
 		case IL_REFPREFIX:
 			lex >> refprefix_;
@@ -440,10 +460,10 @@ bool InsetLayout::read(Lexer & lex, TextClass const & tclass)
 			lex >> htmlisblock_;
 			break;
 		case IL_HTMLSTYLE:
-			htmlstyle_ = from_utf8(lex.getLongString("EndHTMLStyle"));
+			htmlstyle_ = lex.getLongString(from_ascii("EndHTMLStyle"));
 			break;
 		case IL_HTMLPREAMBLE:
-			htmlpreamble_ = from_utf8(lex.getLongString("EndPreamble"));
+			htmlpreamble_ = lex.getLongString(from_ascii("EndPreamble"));
 			break;
 		case IL_REQUIRES: {
 			lex.eatLine();
@@ -584,6 +604,7 @@ void InsetLayout::readArgument(Lexer & lex)
 	arg.font = inherit_font;
 	arg.labelfont = inherit_font;
 	arg.is_toc_caption = false;
+	arg.passthru = PT_INHERITED;
 	string nr;
 	lex >> nr;
 	bool const postcmd = prefixIs(nr, "post:");
@@ -610,9 +631,6 @@ void InsetLayout::readArgument(Lexer & lex)
 		} else if (tok == "insertcotext") {
 			lex.next();
 			arg.insertcotext = lex.getBool();
-		} else if (tok == "insertcotext") {
-			lex.next();
-			arg.insertcotext = lex.getBool();
 		} else if (tok == "leftdelim") {
 			lex.next();
 			arg.ldelim = lex.getDocString();
@@ -645,6 +663,15 @@ void InsetLayout::readArgument(Lexer & lex)
 		} else if (tok == "passthruchars") {
 			lex.next();
 			arg.pass_thru_chars = lex.getDocString();
+		} else if (tok == "passthru") {
+			lex.next();
+			docstring value = lex.getDocString();
+			if (value == "true" || value == "1")
+				arg.passthru = PT_TRUE;
+			else if (value == "false" || value == "0")
+				arg.passthru = PT_FALSE;
+			else
+				arg.passthru = PT_INHERITED;
 		} else if (tok == "istoccaption") {
 			lex.next();
 			arg.is_toc_caption = lex.getBool();
