@@ -31,6 +31,7 @@
 #include "OutputParams.h"
 #include "output_xhtml.h"
 #include "sgml.h"
+#include "texstream.h"
 #include "TocBackend.h"
 
 #include "frontends/FontMetrics.h"
@@ -64,9 +65,12 @@ ParamInfo const & InsetNomencl::findInfo(string const & /* cmdName */)
 	if (param_info_.empty()) {
 		param_info_.add("prefix", ParamInfo::LATEX_OPTIONAL);
 		param_info_.add("symbol", ParamInfo::LATEX_REQUIRED,
-				ParamInfo::HANDLING_LATEXIFY);
+				ParamInfo::ParamHandling(ParamInfo::HANDLING_LATEXIFY
+							 | ParamInfo::HANDLING_INDEX_ESCAPE));
 		param_info_.add("description", ParamInfo::LATEX_REQUIRED,
-				ParamInfo::HANDLING_LATEXIFY);
+				ParamInfo::ParamHandling(ParamInfo::HANDLING_LATEXIFY
+							 | ParamInfo::HANDLING_INDEX_ESCAPE));
+		param_info_.add("literal", ParamInfo::LYX_INTERNAL);
 	}
 	return param_info_;
 }
@@ -133,14 +137,17 @@ int InsetNomencl::docbookGlossary(odocstream & os) const
 void InsetNomencl::validate(LaTeXFeatures & features) const
 {
 	features.require("nomencl");
+	InsetCommand::validate(features);
 }
 
 
 void InsetNomencl::addToToc(DocIterator const & cpit, bool output_active,
-							UpdateType) const
+							UpdateType, TocBackend & backend) const
 {
 	docstring const str = getParam("symbol");
-	buffer().tocBackend().toc("nomencl")->push_back(TocItem(cpit, 0, str, output_active));
+	TocBuilder & b = backend.builder("nomencl");
+	b.pushItem(cpit, str, output_active);
+	b.pop();
 }
 
 
@@ -157,7 +164,7 @@ InsetPrintNomencl::InsetPrintNomencl(Buffer * buf, InsetCommandParams const & p)
 
 ParamInfo const & InsetPrintNomencl::findInfo(string const & /* cmdName */)
 {
-	// The symbol width is set via nomencl's \nomlabelwidth in 
+	// The symbol width is set via nomencl's \nomlabelwidth in
 	// InsetPrintNomencl::latex and not as optional parameter of
 	// \printnomenclature
 	static ParamInfo param_info_;
@@ -179,7 +186,7 @@ docstring InsetPrintNomencl::screenLabel() const
 
 
 struct NomenclEntry {
-	NomenclEntry() {}
+	NomenclEntry() : par(0) {}
 	NomenclEntry(docstring s, docstring d, Paragraph const * p)
 	  : symbol(s), desc(d), par(p)
 	{}
@@ -209,26 +216,26 @@ docstring InsetPrintNomencl::xhtml(XHTMLStream &, OutputParams const & op) const
 		InsetCommand const * ic = inset->asInsetCommand();
 		if (!ic)
 			return docstring();
-		
+
 		// FIXME We need a link to the paragraph here, so we
 		// need some kind of struct.
 		docstring const symbol = ic->getParam("symbol");
 		docstring const desc = ic->getParam("description");
 		docstring const prefix = ic->getParam("prefix");
 		docstring const sortas = prefix.empty() ? symbol : prefix;
-		
+
 		entries[sortas] = NomenclEntry(symbol, desc, &par);
 	}
-	
+
 	if (entries.empty())
 		return docstring();
-	
+
 	// we'll use our own stream, because we are going to defer everything.
 	// that's how we deal with the fact that we're probably inside a standard
 	// paragraph, and we don't want to be.
 	odocstringstream ods;
 	XHTMLStream xs(ods);
-	
+
 	InsetLayout const & il = getLayout();
 	string const & tag = il.htmltag();
 	docstring toclabel = translateIfPossible(from_ascii("Nomenclature"),
@@ -236,12 +243,12 @@ docstring InsetPrintNomencl::xhtml(XHTMLStream &, OutputParams const & op) const
 
 	xs << html::StartTag("div", "class='nomencl'")
 	   << html::StartTag(tag, "class='nomencl'")
-		 << toclabel 
+		 << toclabel
 		 << html::EndTag(tag)
 	   << html::CR()
 	   << html::StartTag("dl")
 	   << html::CR();
-	
+
 	EntryMap::const_iterator eit = entries.begin();
 	EntryMap::const_iterator const een = entries.end();
 	for (; eit != een; ++eit) {
@@ -357,8 +364,11 @@ docstring nomenclWidest(Buffer const & buffer, OutputParams const & runparams)
 			if (inset->lyxCode() != NOMENCL_CODE)
 				continue;
 			nomencl = static_cast<InsetNomencl const *>(inset);
-			docstring const symbol =
-				nomencl->getParam("symbol");
+			// Use proper formatting. We do not escape makeindex chars here
+			docstring const symbol = nomencl ?
+				nomencl->params().prepareCommand(runparams, nomencl->getParam("symbol"),
+							ParamInfo::HANDLING_LATEXIFY)
+				: docstring();
 			// This is only an approximation,
 			// but the best we can get.
 			int const wx = use_gui ?
@@ -371,19 +381,9 @@ docstring nomenclWidest(Buffer const & buffer, OutputParams const & runparams)
 		}
 	}
 	// return the widest (or an empty) string
-	if (symb.empty())
-		return symb;
-
-	// we have to encode the string properly
-	pair<docstring, docstring> latex_symb =
-		runparams.encoding->latexString(symb, runparams.dryrun);
-	if (!latex_symb.second.empty())
-		LYXERR0("Omitting uncodable characters '"
-			<< latex_symb.second
-			<< "' in nomencl widest string!");
-	return latex_symb.first;
+	return symb;
 }
-} // namespace anon
+} // namespace
 
 
 void InsetPrintNomencl::latex(otexstream & os, OutputParams const & runparams_in) const
@@ -406,7 +406,8 @@ void InsetPrintNomencl::latex(otexstream & os, OutputParams const & runparams_in
 		   << from_ascii(getCmdName())
 		   << '['
 		   << from_ascii(width)
-		   << "]{}";
+		   << "]"
+		   << termcmd;
 		return;
 	}
 	// output the command \printnomenclature
@@ -416,6 +417,7 @@ void InsetPrintNomencl::latex(otexstream & os, OutputParams const & runparams_in
 
 void InsetPrintNomencl::validate(LaTeXFeatures & features) const
 {
+	features.useInsetLayout(getLayout());
 	features.require("nomencl");
 }
 
