@@ -53,6 +53,9 @@ class InsetTableCell : public InsetText
 public:
 	///
 	InsetTableCell(Buffer * buf);
+	/// We need this since generation of the default is deprecated
+	/// (since we declare the assignment constuctor below).
+	InsetTableCell(InsetTableCell const & in) = default;
 	///
 	InsetCode lyxCode() const { return CELL_CODE; }
 	///
@@ -72,6 +75,8 @@ public:
 	///
 	void addToToc(DocIterator const & di, bool output_active,
 				  UpdateType utype, TocBackend & backend) const;
+	/// This assures we never output \maketitle in table cells
+	bool isInTitle() const { return true; }
 private:
 	/// unimplemented
 	InsetTableCell();
