@@ -53,6 +53,8 @@
 
 #include "support/regex.h"
 
+#include <iterator>
+
 using namespace std;
 using namespace lyx::support;
 
@@ -1455,6 +1457,7 @@ static void findAdvReplace(BufferView * bv, FindAndReplaceOptions const & opt, M
 	repl_buffer_orig.write(oss);
 	string lyx = oss.str();
 	Buffer repl_buffer("", false);
+	repl_buffer.setInternal(true);
 	repl_buffer.setUnnamed(true);
 	LASSERT(repl_buffer.readString(lyx), return);
 	if (opt.keep_case && sel_len >= 2) {
