@@ -81,22 +81,20 @@ void InsetMathBox::htmlize(HtmlStream & ms) const
 
 void InsetMathBox::metrics(MetricsInfo & mi, Dimension & dim) const
 {
-	FontSetChanger dummy(mi.base, "textnormal");
+	Changer dummy = mi.base.changeFontSet("textnormal");
 	cell(0).metrics(mi, dim);
-	metricsMarkers(dim);
 }
 
 
 void InsetMathBox::draw(PainterInfo & pi, int x, int y) const
 {
-	FontSetChanger dummy(pi.base, "textnormal");
+	Changer dummy = pi.base.changeFontSet("textnormal");
 	cell(0).draw(pi, x, y);
-	drawMarkers(pi, x, y);
 }
 
 
 void InsetMathBox::infoize(odocstream & os) const
-{	
+{
 	os << bformat(_("Box: %1$s"), name_);
 }
 
@@ -133,9 +131,12 @@ InsetMathFBox::InsetMathFBox(Buffer * buf)
 
 void InsetMathFBox::metrics(MetricsInfo & mi, Dimension & dim) const
 {
-	FontSetChanger dummy(mi.base, "textnormal");
+	Changer dummy = mi.base.changeFontSet("textnormal");
 	cell(0).metrics(mi, dim);
-	metricsMarkers2(dim, 3); // 1 pixel space, 1 frame, 1 space
+	// 1 pixel space, 1 frame, 1 space
+	dim.wid += 2 * 3;
+	dim.asc += 3;
+	dim.des += 3;
 }
 
 
@@ -144,9 +145,8 @@ void InsetMathFBox::draw(PainterInfo & pi, int x, int y) const
 	Dimension const dim = dimension(*pi.base.bv);
 	pi.pain.rectangle(x + 1, y - dim.ascent() + 1,
 		dim.width() - 2, dim.height() - 2, Color_foreground);
-	FontSetChanger dummy(pi.base, "textnormal");
+	Changer dummy = pi.base.changeFontSet("textnormal");
 	cell(0).draw(pi, x + 3, y);
-	setPosCache(pi, x, y);
 }
 
 
@@ -164,7 +164,7 @@ void InsetMathFBox::normalize(NormalStream & os) const
 
 
 void InsetMathFBox::mathmlize(MathStream & ms) const
-{	
+{
 	SetMode textmode(ms, true);
 	ms << MTag("mstyle", "class='fbox'")
 	   << cell(0)
@@ -219,24 +219,24 @@ InsetMathMakebox::InsetMathMakebox(Buffer * buf, bool framebox)
 
 void InsetMathMakebox::metrics(MetricsInfo & mi, Dimension & dim) const
 {
-	FontSetChanger dummy(mi.base, "textnormal");
-	
+	Changer dummy = mi.base.changeFontSet("textnormal");
+
 	Dimension wdim;
 	static docstring bracket = from_ascii("[");
 	metricsStrRedBlack(mi, wdim, bracket);
 	int w = wdim.wid;
-	
+
 	Dimension dim0;
 	Dimension dim1;
 	Dimension dim2;
 	cell(0).metrics(mi, dim0);
 	cell(1).metrics(mi, dim1);
 	cell(2).metrics(mi, dim2);
-	
+
 	dim.wid = w + dim0.wid + w + w + dim1.wid + w + 2 + dim2.wid;
-	dim.asc = std::max(std::max(wdim.asc, dim0.asc), std::max(dim1.asc, dim2.asc)); 
+	dim.asc = std::max(std::max(wdim.asc, dim0.asc), std::max(dim1.asc, dim2.asc));
 	dim.des = std::max(std::max(wdim.des, dim0.des), std::max(dim1.des, dim2.des));
-	
+
 	if (framebox_) {
 		dim.wid += 4;
 		dim.asc += 3;
@@ -245,26 +245,22 @@ void InsetMathMakebox::metrics(MetricsInfo & mi, Dimension & dim) const
 		dim.asc += 1;
 		dim.des += 1;
 	}
-	
-	metricsMarkers(dim);
 }
 
 
 void InsetMathMakebox::draw(PainterInfo & pi, int x, int y) const
 {
-	drawMarkers(pi, x, y);
-	
-	FontSetChanger dummy(pi.base, "textnormal");
+	Changer dummy = pi.base.changeFontSet("textnormal");
 	BufferView const & bv = *pi.base.bv;
 	int w = mathed_char_width(pi.base.font, '[');
-	
+
 	if (framebox_) {
 		Dimension const dim = dimension(*pi.base.bv);
 		pi.pain.rectangle(x + 1, y - dim.ascent() + 1,
 				  dim.width() - 2, dim.height() - 2, Color_foreground);
 		x += 2;
 	}
-	
+
 	drawStrBlack(pi, x, y, from_ascii("["));
 	x += w;
 	cell(0).draw(pi, x, y);
@@ -305,7 +301,7 @@ void InsetMathMakebox::normalize(NormalStream & os) const
 
 void InsetMathMakebox::infoize(odocstream & os) const
 {
-	os << (framebox_ ? "Framebox" : "Makebox") 
+	os << (framebox_ ? "Framebox" : "Makebox")
 	   << " (width: " << cell(0)
 	   << " pos: " << cell(1) << ")";
 }
@@ -360,7 +356,10 @@ InsetMathBoxed::InsetMathBoxed(Buffer * buf)
 void InsetMathBoxed::metrics(MetricsInfo & mi, Dimension & dim) const
 {
 	cell(0).metrics(mi, dim);
-	metricsMarkers2(dim, 3); // 1 pixel space, 1 frame, 1 space
+	// 1 pixel space, 1 frame, 1 space
+	dim.wid += 2 * 3;
+	dim.asc += 3;
+	dim.des += 3;
 }
 
 
@@ -370,7 +369,6 @@ void InsetMathBoxed::draw(PainterInfo & pi, int x, int y) const
 	pi.pain.rectangle(x + 1, y - dim.ascent() + 1,
 		dim.width() - 2, dim.height() - 2, Color_foreground);
 	cell(0).draw(pi, x + 3, y);
-	setPosCache(pi, x, y);
 }
 
 
@@ -420,7 +418,7 @@ void InsetMathBoxed::validate(LaTeXFeatures & features) const
 		features.addCSSSnippet("mstyle.boxed { border: 1px solid black; }");
 	else if (features.runparams().math_flavor == OutputParams::MathAsHTML)
 		features.addCSSSnippet("span.boxed { border: 1px solid black; }");
-	
+
 	InsetMathNest::validate(features);
 }
 
