@@ -26,6 +26,7 @@
 #include "BufferView.h"
 #include "CoordCache.h"
 #include "Cursor.h"
+#include "Encoding.h"
 #include "FuncStatus.h"
 #include "FuncRequest.h"
 #include "LaTeXFeatures.h"
@@ -33,6 +34,7 @@
 #include "LyXRC.h"
 #include "MetricsInfo.h"
 
+#include "frontends/alert.h"
 #include "frontends/Painter.h"
 
 #include "support/debug.h"
@@ -908,14 +910,18 @@ void InsetMathMacro::validate(LaTeXFeatures & features) const
 			features.require(data->requires());
 	}
 
-	if (name() == "binom")
-		features.require("binom");
-
 	// validate the cells and the definition
 	if (displayMode() == DISPLAY_NORMAL) {
 		d->definition_.validate(features);
-		InsetMathNest::validate(features);
+	} else if (displayMode() == DISPLAY_INIT) {
+		MathData ar(const_cast<Buffer *>(&buffer()));
+		MacroData const * data = buffer().getMacro(name());
+		if (data) {
+			asArray(data->definition(), ar);
+			ar.validate(features);
+		}
 	}
+	InsetMathNest::validate(features);
 }
 
 
@@ -1070,10 +1076,55 @@ void InsetMathMacro::write(WriteStream & os) const
 	mode_type mode = currentMode();
 	MathEnsurer ensurer(os, mode == MATH_MODE, true, mode == TEXT_MODE);
 
+	// Check if the macro name is encodable. Otherwise we might crash (#11855).
+	docstring const name_in = name();
+	docstring name_recoded;
+	docstring uncodable;
+	for (char_type c : name_in) {
+		if (!os.encoding()) {
+			name_recoded += c;
+			continue;
+		}
+		if (os.encoding()->encodable(c))
+			name_recoded += c;
+		else {
+			switch (os.output()) {
+			case WriteStream::wsDryrun: {
+				os << "<" << _("LyX Warning: ")
+				   << _("uncodable character") << " '";
+				os << docstring(1, c);
+				os << "'>";
+				break;
+			}
+			case WriteStream::wsPreview: {
+				// indicate the encoding error by a boxed '?'
+				os << "{\\fboxsep=1pt\\fbox{?}}";
+				LYXERR0("Uncodable character" << " '"
+					<< docstring(1, c)
+					<< "'");
+				break;
+			}
+			case WriteStream::wsDefault:
+			default:
+				// record for error message
+				uncodable += c;
+				break;
+			}
+		}
+	}
+	
+	if (!uncodable.empty()) {
+		frontend::Alert::warning(
+			_("Uncodable characters in math macro"),
+			support::bformat(_("The macro name '%1$s' contains a character\n"
+					   "that is not encodable in the current encoding (%2$s).\n"
+					   "Please fix this macro."), name_in, uncodable));
+	}
+
 	// non-normal mode
 	if (d->displayMode_ != DISPLAY_NORMAL) {
-		os << "\\" << name();
-		if (name().size() != 1 || isAlphaASCII(name()[0]))
+		os << "\\" << name_recoded;
+		if (name_recoded.size() != 1 || isAlphaASCII(name_recoded[0]))
 			os.pendingSpace(true);
 		return;
 	}
@@ -1086,7 +1137,7 @@ void InsetMathMacro::write(WriteStream & os) const
 	if (os.fragile())
 		os << "\\protect";
 
-	os << "\\" << name();
+	os << "\\" << name_recoded;
 	bool first = true;
 
 	// Optional arguments:
