@@ -566,11 +566,6 @@ void InsetMathNest::doDispatch(Cursor & cur, FuncRequest & cmd)
 		cur.forceBufferUpdate();
 		break;
 
-	case LFUN_COPY:
-		copySelection(cur);
-		cur.message(_("Copy"));
-		break;
-
 	case LFUN_MOUSE_PRESS:
 		lfunMousePress(cur, cmd);
 		break;
@@ -1771,7 +1766,13 @@ bool InsetMathNest::interpretChar(Cursor & cur, char_type const c)
 			// but suppress direct insertion of two spaces in a row
 			// the still allows typing  '<space>a<space>' and deleting the 'a', but
 			// it is better than nothing...
-			if (cur.pos() == 0 || cur.prevAtom()->getChar() != ' ') {
+			pos_type const pos = cur.pos();
+			pos_type const lastpos = cur.lastpos();
+			if ((pos == 0 && lastpos == 0)
+			    || (pos == 0 && cur.nextAtom()->getChar() != ' ')
+			    || (pos == lastpos && cur.prevAtom()->getChar() != ' ')
+			    || (pos > 0 && cur.prevAtom()->getChar() != ' '
+					&& cur.nextAtom()->getChar() != ' ')) {
 				cur.insert(c);
 				// FIXME: we have to enable full redraw here because of the
 				// visual box corners that define the inset. If we know for
