@@ -40,7 +40,7 @@ public:
 	///
 	mode_type currentMode() const;
 	///
-	bool isRelOp() const;
+	MathClass mathClass() const;
 	///
 	bool isOrdAlpha() const;
 	/// do we take scripts?
