@@ -29,8 +29,6 @@ public:
 	///
 	void metrics(MetricsInfo & mi, Dimension & dim) const;
 	///
-	Dimension const dimension(BufferView const &) const;
-	///
 	void draw(PainterInfo & pi, int x, int y) const;
 	///
 	InsetMathTabular * asTabularInset() { return this; }
@@ -47,7 +45,11 @@ public:
 	void maple(MapleStream &) const;
 	///
 	InsetCode lyxCode() const { return MATH_TABULAR_CODE; }
-	/// 
+	///
+	int leftMargin() const { return 4; } //override
+	///
+	int rightMargin() const { return 2; } //override
+	///
 	bool handlesMulticolumn() const { return true; } //override
 
 private:
