@@ -344,6 +344,11 @@ static void finishEnvironment(otexstream & os, OutputParams const & runparams,
 				popLanguageName();
 			}
 		}
+		if (data.style->latextype == LATEX_BIB_ENVIRONMENT)
+			// bibliography needs a blank line after
+			// each item for backref to function properly
+			// (see #12041)
+			os << '\n';
 		state->nest_level_ -= 1;
 		string const & name = data.style->latexname();
 		if (!name.empty())
@@ -1570,7 +1575,7 @@ void latexParagraphs(Buffer const & buf,
 			<< '\n';
 		// If we have language_auto_begin, the stack will
 		// already be empty, nothing to pop()
-		if (using_begin_end && !lyxrc.language_auto_begin)
+		if (using_begin_end && langOpenedAtThisLevel(state))
 			popLanguageName();
 	}
 
