@@ -28,7 +28,7 @@
 #include <QFileInfo>
 #include <QList>
 #include <QTemporaryFile>
-#include <QTime>
+#include <QElapsedTimer>
 
 #ifdef _WIN32
 #include <QThread>
@@ -251,6 +251,7 @@ bool FileName::renameTo(FileName const & name) const
 {
 	LYXERR(Debug::FILES, "Renaming " << name << " as " << *this);
 	bool success = QFile::rename(d->fi.absoluteFilePath(), name.d->fi.absoluteFilePath());
+	d->refresh();
 	if (!success)
 		LYXERR0("Could not rename file " << *this << " to " << name);
 	return success;
@@ -264,12 +265,13 @@ bool FileName::moveTo(FileName const & name) const
 	// there's a locking problem on Windows sometimes, so
 	// we will keep trying for five seconds, in the hope
 	// that clears.
+	name.refresh();
 	if (name.exists()) {
-		bool removed = QFile::remove(name.d->fi.absoluteFilePath());
+		bool removed = name.removeFile();
 		int tries = 1;
 		while (!removed && tries < 6)	{
 			QThread::sleep(1);
-			removed = QFile::remove(name.d->fi.absoluteFilePath());
+			removed = name.removeFile();
 			tries++;
 		}
 	}
@@ -277,8 +279,7 @@ bool FileName::moveTo(FileName const & name) const
 	QFile::remove(name.d->fi.absoluteFilePath());
 #endif
 
-	bool const success = QFile::rename(d->fi.absoluteFilePath(),
-		name.d->fi.absoluteFilePath());
+	bool const success = renameTo(name);
 	if (!success)
 		LYXERR0("Could not move file " << *this << " to " << name);
 	return success;
@@ -506,7 +507,11 @@ time_t FileName::lastModified() const
 	// been touched between the object creation and now, we refresh the file
 	// information.
 	d->refresh();
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 8, 0))
+	return d->fi.lastModified().toSecsSinceEpoch();
+#else
 	return d->fi.lastModified().toTime_t();
+#endif
 }
 
 
@@ -553,7 +558,7 @@ unsigned long FileName::checksum() const
 	}
 
 	// This is used in the debug output at the end of the method.
-	static QTime t;
+	static QElapsedTimer t;
 	if (lyxerr.debugging(Debug::FILES))
 		t.restart();
 
@@ -619,7 +624,7 @@ unsigned long FileName::checksum() const
 #endif // QT_VERSION
 
 	LYXERR(Debug::FILES, "Checksumming \"" << absFileName() << "\" "
-		<< result << " lasted " << t.elapsed() << " ms.");
+		<< result << " lasted " << QString::number(t.elapsed()) << " ms.");
 	return result;
 }
 
